
<template>
  <a-modal
    :title="title"
    :width="900"
    :visible="visible"
    :maskClosable="false"
    :confirmLoading="confirmLoading"
    :okButtonProps="{ props: {disabled: disableSubmit} }"
    @ok="handleOk"
    @cancel="handleCancel"
    cancelText="关闭"
  >
    <a-spin :spinning="confirmLoading">
      <a-form :form="form">
        <a-row style="width: 100%">
          <a-col :span="12">
            <a-form-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              label="备件编号"
            >
              <a-input-search
                placeholder="请选择备件"
                enter-button
                @search="onSearchSparePart()"
                v-decorator="['sparePartNum',validatorRules.sparePartNum]"
                :read-only="true"
              />
            </a-form-item>
          </a-col>
          <a-col :span="24/2" >
            <a-form-item label="备件名称" :labelCol="labelCol" :wrapperCol="wrapperCol">
              <a-input :disabled="true" v-decorator="['sparePartName', validatorRules.sparePartName]" placeholder="请输入设备名称" ></a-input>
            </a-form-item>
          </a-col>
          <a-col :span="24/2" >
            <a-form-item label="备件型号" :labelCol="labelCol" :wrapperCol="wrapperCol">
              <a-input :disabled="true"  v-decorator="['sparePartModel', validatorRules.sparePartModel]" placeholder="请输入设备型号" ></a-input>
            </a-form-item>
          </a-col>
          <a-col :span="24/2" >
            <a-form-item label="备件规格" :labelCol="labelCol" :wrapperCol="wrapperCol">
              <a-input :disabled="true"  v-decorator="['sparePartSpecification', validatorRules.sparePartSpecification]" placeholder="请输入设备规格" ></a-input>
            </a-form-item>
          </a-col>
          <a-col :span="24/2" >
            <a-form-item label="制造商" :labelCol="labelCol" :wrapperCol="wrapperCol">
              <a-input :disabled="true"  v-decorator="['constructorName', validatorRules.constructorName]" placeholder="请输入制造商" ></a-input>
            </a-form-item>
          </a-col>
          <a-col :span="24/2" >
            <a-form-item label="单位" :labelCol="labelCol" :wrapperCol="wrapperCol">
              <a-input :disabled="true"  v-decorator="['mainUnitName', validatorRules.mainUnitName]" placeholder="请输入单位" ></a-input>
            </a-form-item>
          </a-col>
          <a-col :span="24">
            <a-form-item
              :labelCol="{span:3}" 
              :wrapperCol="{span:21}"
              label="数量"
            >
              <a-input-number
                style="width: 100%"
                placeholder="请输入数量"
                v-decorator="['quantity', validatorRules.quantity]"
              />
            </a-form-item>
          </a-col>
        </a-row>
      </a-form>
    </a-spin>

    <template slot="footer">
      <a-button
        :style="{marginRight: '8px'}"
        @click="handleCancel"
      >
        关闭
      </a-button>
      <a-button
        :disabled="disableSubmit || confirmLoading"
        :loading="confirmLoading"
        @click="handleOk"
        type="primary"
      >确定</a-button>
    </template>

    <plan-spare-part-select
      ref="planSparePartSelect"
      @sendSparePartRecord='sendSparePartRecord'
    ></plan-spare-part-select>

  </a-modal>
</template>

<script>
import pick from 'lodash.pick'
import { postAction, requestPut } from '@/api/manage'
import { duplicateCheck } from '@/api/api'
import PlanSparePartSelect from './moudles/select/PlanSparePartSelect.vue'


export default {
  name: 'MaintenanceStandardPlanningMaterialModal',
  components: {
    PlanSparePartSelect
  },
  props:{
    mainId:{
        type:String,
        required:false,
        default:''
      }
  },
  data() {
    return {
      title: "操作",
      visible: false,
      codeDisable: true,
      disableSubmit: false,
      maintenanceStandardId: '',
      sparePartId: '',
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 6 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 18 },
      },
      confirmLoading: false,
      form: this.$form.createForm(this),
      validatorRules: {
        sparePartName: {
          rules: [
            { required: true, message: '请选择备件!' },
          ]
        },
        quantity: {
          rules: [
            { required: true, message: '请输入数量!' },
          ]
        }
      },
      url: {
        add: "/eam/maintenanceStandardPlanningMaterial/add",
        edit: "/eam/maintenanceStandardPlanningMaterial/edit"
      },
      //新增、编辑、删除、批量删除操作改变数据后刷新关联的组件的监听属性
      alterFlag: "",
    }
  },
  created() {
  },
  methods: {

    add() {
      this.edit({});
    },

    edit(record) {
      this.form.resetFields();
      this.model = Object.assign({}, record);
      this.visible = true;
      this.disableSubmit = false;
      this.$nextTick(() => {
        this.form.setFieldsValue(pick(this.model,
          'sparePartNum',
          'sparePartName',
          'sparePartModel',
          'sparePartSpecification',
          'mainUnitName',
          'constructorName',
          'quantity'));
      });
      if (record.id) {
        this.codeDisable = true;
      } else {
        this.codeDisable = false;
      }
    },

    close() {
      this.$emit('close');
      this.visible = false;
    },

    //保存并新增按钮触发


    handleOk() {
      const that = this;
      // 触发表单验证
      this.form.validateFields((err, values) => {
        if (!err) {
          that.confirmLoading = true;
          let formData = Object.assign(this.model, values);
          formData.maintenanceStandardId = this.mainId;
          formData.sparePartId = this.sparePartId
          let obj;
          if (!this.model.id) {
            obj = postAction(this.url.add, formData);
          } else {
            obj = requestPut(this.url.edit, formData, { id: this.model.id });
          }
          obj.then((res) => {
            if (res.success) {
              that.$message.success(res.message);
              that.$emit('ok');
              that.alterFlag = new Date();
            } else {
              that.$message.warning(res.message);
            }
          }).finally(() => {
            that.confirmLoading = false;
            that.close();
          })
        }
      })
    },

    onSearchSparePart() {
      this.$refs.planSparePartSelect.list();
      this.$refs.planSparePartSelect.title = "选择备件";
    },
    sendSparePartRecord(data) {
      let record = data.record;
      this.sparePartId = record.id;
      this.form.setFieldsValue({ sparePartId : record.id,sparePartNum: record.num,sparePartName: record.name,sparePartModel: record.model,
        sparePartSpecification: record.specification,mainUnitId:record.mainUnitId,mainUnitName: record.mainUnitId_dictText,constructorName:record.constructorId_dictText });
    },

    handleCancel() {
      this.close()
    },

  },
}
</script>

<style scoped>
.ant-btn {
  padding: 0 10px;
  margin-left: 3px;
}

.ant-form-item-control {
  line-height: 0px;
}

/** 主表单行间距 */
.ant-form .ant-form-item {
  margin-bottom: 10px;
}

/** Tab页面行间距 */
.ant-tabs-content .ant-form-item {
  margin-bottom: 0px;
}
</style>
